Package: shiny.blueprint
Title: Palantir's 'Blueprint' for 'Shiny' Apps
Version: 0.3.0
Authors@R: 
  c(
    person("Jakub", "Sobolewski", role = c("aut", "cre"), email = "opensource+jakub.sobolewski@appsilon.com"),
    person("Kamil", "Żyła", role = "aut", email = "kamil@appsilon.com"),
    person("Filip", "Akkad", role = "aut", email = "filip.akkad@filpro.io"),
    person("Filip", "Stachura", role = "aut", email = "filip@appsilon.com"),
    person("Paweł", "Chabros", role = "aut", email = "pawel.chabros@yahoo.pl"),
    person("Appsilon Sp. z o.o.", role = "cph", email = "opensource@appsilon.com")
  )
Description: 
  Easily use 'Blueprint', the popular 'React' library from Palantir, in your 'Shiny' app.
  'Blueprint' provides a rich set of UI components for creating visually appealing applications
  and is optimized for building complex, data-dense web interfaces.
  This package provides most components from the underlying library,
  as well as special wrappers for some components
  to make it easy to use them in 'R' without writing 'JavaScript' code.
License: LGPL-3
Encoding: UTF-8
RoxygenNote: 7.3.1
VignetteBuilder: knitr
Imports: checkmate, htmltools, shiny, shiny.react (>= 0.4.0), utils
Suggests: covr, knitr, lintr (>= 3.0.0), purrr, rcmdcheck, rmarkdown,
        shiny.router
NeedsCompilation: no
Packaged: 2024-05-21 07:06:38 UTC; jakub
Author: Jakub Sobolewski [aut, cre],
  Kamil Żyła [aut],
  Filip Akkad [aut],
  Filip Stachura [aut],
  Paweł Chabros [aut],
  Appsilon Sp. z o.o. [cph]
Maintainer: Jakub Sobolewski <opensource+jakub.sobolewski@appsilon.com>
Repository: CRAN
Date/Publication: 2024-05-21 11:20:11 UTC
Built: R 4.6.0; ; 2026-04-26 15:07:15 UTC; unix
